package uk.ac.cf.spring.demo.sports.Userdetail;

import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.servlet.ModelAndView;

import java.util.List;

@Controller
public class UserController {
    // 依赖注入 UserService
    private final UserService userService;

    public UserController(UserService userService) {
        this.userService = userService;
    }

    // 显示所有用户列表
    @GetMapping("/users")
    public ModelAndView getUsers() {
        ModelAndView modelAndView = new ModelAndView("user/allUserList");
        List<User> users = userService.getAllUsers();
        modelAndView.addObject("users", users);
        return modelAndView;
    }

    // 通过用户 ID 查看用户详情
    @GetMapping("/users/{id}")
    public ModelAndView getUserById(@PathVariable Long id) {
        ModelAndView modelAndView = new ModelAndView("user/userDetails");
        User user = userService.getUserById(id);
        modelAndView.addObject("user", user);
        return modelAndView;
    }

    // 显示添加用户的表单
    @GetMapping("/users/add")
    public ModelAndView addUser() {
        ModelAndView modelAndView = new ModelAndView("user/userForm");
        Userform emptyUserform = new Userform();
        modelAndView.addObject("user", emptyUserform);
        return modelAndView;
    }

    // 显示编辑用户信息的表单
    @GetMapping("/users/edit/{id}")
    public ModelAndView editUser(@PathVariable("id") Long id) {
        ModelAndView modelAndView = new ModelAndView("user/userForm");
        // 获取需要编辑的用户
        User userToEdit = userService.getUserById(id);

        // 创建表单对象
        Userform userform = new Userform(
                userToEdit.getId(),
                userToEdit.getEmail(),
                userToEdit.getUsername()
        );

        modelAndView.addObject("user", userform);
        return modelAndView;
    }
}